@@ -6,18 +6,21 @@ from .exceptions import SessionException, SessionClosedException, SessionNotFoun
 from .utils import STATIC_PATH
 
 from .__version__ import __description__, __url__, __version__
-from .__version__ import __author__, __author_email__, __license__, __copyright__
+from .__version__ import __author__, __author_email__, __license__
+
+from .platform.bokeh import try_install_bokeh_hook
+
+try_install_bokeh_hook()
+del try_install_bokeh_hook
 
 # Set default logging handler to avoid "No handler found" warnings.
 import logging
-from logging import NullHandler, StreamHandler
-
-logging.getLogger(__name__).addHandler(NullHandler())
+logging.getLogger(__name__).addHandler(logging.NullHandler())
 
 
 def enable_debug(level=logging.DEBUG):
     """Output PyWebIO logging message to sys.stderr"""
-    ch = StreamHandler()
+    ch = logging.StreamHandler()
     ch.setLevel(level)
     formatter = logging.Formatter('[%(levelname)s %(asctime)s %(module)s:%(lineno)d %(funcName)s] %(message)s',
                                   datefmt='%y%m%d %H:%M:%S')
