@@ -1,40 +1,32 @@
 import logging
 import queue
-import sys
 import threading
-import traceback
 from functools import wraps
 
-from .base import AbstractSession
+from .base import Session
 from ..exceptions import SessionNotFoundException, SessionClosedException, SessionException
-from ..utils import random_str, LimitedSizeQueue, isgeneratorfunction, iscoroutinefunction, catch_exp_call, get_function_name
+from ..utils import random_str, LimitedSizeQueue, isgeneratorfunction, iscoroutinefunction, \
+    get_function_name
 
 logger = logging.getLogger(__name__)
 
 """
 基于线程的会话实现
 
-主任务线程退出后，连接关闭，但不会清理主任务线程产生的其他线程
-
-客户端连接关闭后，后端线程不会退出，但是再次调用输入输出函数会引发异常
-todo: thread 重名
+当任务函数返回并且会话内所有的通过 register_thread(thread) 注册的线程都退出后，会话结束，连接关闭。
+正在等待PyWebIO输入的线程会在输入函数中抛出SessionClosedException异常，
+其他线程若调用PyWebIO输入输出函数会引发异常SessionException
 """
 
 
 # todo 线程安全
-class ThreadBasedSession(AbstractSession):
+class ThreadBasedSession(Session):
     thread2session = {}  # thread_id -> session
 
     unhandled_task_mq_maxsize = 1000
     event_mq_maxsize = 100
     callback_mq_maxsize = 100
 
-    _active_session_cnt = 0
-
-    @classmethod
-    def active_session_count(cls):
-        return cls._active_session_cnt
-
     @classmethod
     def get_current_session(cls) -> "ThreadBasedSession":
         curr = id(threading.current_thread())
@@ -54,27 +46,24 @@ class ThreadBasedSession(AbstractSession):
         tname = getattr(tname, '__name__', tname)
         return '%s-%s' % (tname, id(thread))
 
-    def __init__(self, target, on_task_command=None, on_session_close=None, loop=None):
+    def __init__(self, target, session_info, on_task_command=None, on_session_close=None, loop=None):
         """
-        :param target: 会话运行的函数
+        :param target: 会话运行的函数. 为None时表示Script mode
         :param on_task_command: 当Task内发送Command给session的时候触发的处理函数
         :param on_session_close: 会话结束的处理函数
         :param loop: 事件循环。若 on_task_command 或者 on_session_close 中有调用使用asyncio事件循环的调用，
             则需要事件循环实例来将回调在事件循环的线程中执行
         """
-        assert (not iscoroutinefunction(target)) and (not isgeneratorfunction(target)), ValueError(
+        assert target is None or (not iscoroutinefunction(target)) and (not isgeneratorfunction(target)), ValueError(
             "ThreadBasedSession only accept a simple function as task function, "
             "not coroutine function or generator function. ")
 
-        ThreadBasedSession._active_session_cnt += 1
+        super().__init__(session_info)
 
         self._on_task_command = on_task_command or (lambda _: None)
         self._on_session_close = on_session_close or (lambda: None)
         self._loop = loop
 
-        # 会话结束时运行的函数
-        self.deferred_functions = []
-
         self.threads = []  # 注册到当前会话的线程集合
         self.unhandled_task_msgs = LimitedSizeQueue(maxsize=self.unhandled_task_mq_maxsize)
 
@@ -86,7 +75,8 @@ class ThreadBasedSession(AbstractSession):
         self.callback_thread = None
         self.callbacks = {}  # callback_id -> (callback_func, is_mutex)
 
-        self._start_main_task(target)
+        if target is not None:
+            self._start_main_task(target)
 
     def _start_main_task(self, target):
 
@@ -167,6 +157,7 @@ class ThreadBasedSession(AbstractSession):
             self._on_session_close()
 
     def _cleanup(self):
+        cls = type(self)
 
         self.unhandled_task_msgs.wait_empty(8)
         if not self.unhandled_task_msgs.empty():
@@ -174,7 +165,7 @@ class ThreadBasedSession(AbstractSession):
             raise RuntimeError('There are unhandled task messages when session close!')
 
         for t in self.threads:
-            del ThreadBasedSession.thread2session[id(t)]
+            del cls.thread2session[id(t)]
 
         if self.callback_mq is not None:  # 回调功能已经激活
             self.callback_mq.put(None)  # 结束回调线程
@@ -184,37 +175,16 @@ class ThreadBasedSession(AbstractSession):
 
         self.task_mqs = {}
 
-        ThreadBasedSession._active_session_cnt -= 1
-
     def close(self):
         """关闭当前Session。由Backend调用"""
         # todo self._closed 会有竞争条件
-        if self._closed:
+        if self.closed():
             return
-        self._closed = True
+
+        super().close()
 
         self._cleanup()
 
-        self.deferred_functions.reverse()
-        while self.deferred_functions:
-            func = self.deferred_functions.pop()
-            catch_exp_call(func, logger)
-
-    def closed(self):
-        return self._closed
-
-    def on_task_exception(self):
-        from ..output import put_markdown  # todo
-        logger.exception('Error in thread executing')
-        type, value, tb = sys.exc_info()
-        tb_len = len(list(traceback.walk_tb(tb)))
-        lines = traceback.format_exception(type, value, tb, limit=1 - tb_len)
-        traceback_msg = ''.join(lines)
-        try:
-            put_markdown("发生错误：\n```\n%s\n```" % traceback_msg)
-        except:
-            pass
-
     def _activate_callback_env(self):
         """激活回调功能
 
@@ -230,6 +200,9 @@ class ThreadBasedSession(AbstractSession):
                                                 daemon=True, name='callback-' + random_str(10))
         # self.register_thread(self.callback_thread)
         self.thread2session[id(self.callback_thread)] = self  # 用于在线程内获取会话
+        event_mq = queue.Queue(maxsize=self.event_mq_maxsize)  # 线程内的用户事件队列
+        self.task_mqs[self._get_task_id(self.callback_thread)] = event_mq
+
         self.callback_thread.start()
         logger.debug('Callback thread start')
 
@@ -250,7 +223,7 @@ class ThreadBasedSession(AbstractSession):
             def run(callback):
                 try:
                     callback(event['data'])
-                except:
+                except Exception:
                     # 子类可能会重写 get_current_session ，所以不要用 ThreadBasedSession.get_current_session 来调用
                     self.get_current_session().on_task_exception()
 
@@ -265,9 +238,7 @@ class ThreadBasedSession(AbstractSession):
     def register_callback(self, callback, serial_mode=False):
         """ 向Session注册一个回调函数，返回回调id
 
-        Session需要保证当收到前端发送的事件消息 ``{event: "callback"，task_id: 回调id, data:...}`` 时，
-        ``callback`` 回调函数被执行， 并传入事件消息中的 ``data`` 字段值作为参数
-
+        :param Callable callback: 回调函数. 函数签名为 ``callback(data)``. ``data`` 参数为回调事件的值
         :param bool serial_mode: 串行模式模式。若为 ``True`` ，则对于同一组件的点击事件，串行执行其回调函数
         """
         assert (not iscoroutinefunction(callback)) and (not isgeneratorfunction(callback)), ValueError(
@@ -290,10 +261,6 @@ class ThreadBasedSession(AbstractSession):
         event_mq = queue.Queue(maxsize=self.event_mq_maxsize)  # 线程内的用户事件队列
         self.task_mqs[self._get_task_id(t)] = event_mq
 
-    def defer_call(self, func):
-        """设置会话结束时调用的函数。可以用于资源清理。"""
-        self.deferred_functions.append(func)
-
 
 class ScriptModeSession(ThreadBasedSession):
     """Script mode的会话实现"""
@@ -316,8 +283,9 @@ class ScriptModeSession(ThreadBasedSession):
 
     instance = None
 
-    def __init__(self, thread, on_task_command=None, loop=None):
+    def __init__(self, thread, session_info, on_task_command=None, loop=None):
         """
+        :param thread: 第一次调用PyWebIO交互函数的线程 todo 貌似本参数并不必要
         :param on_task_command: 会话结束的处理函数。后端Backend在相应on_session_close时关闭连接时，
             需要保证会话内的所有消息都传送到了客户端
         :param loop: 事件循环。若 on_task_command 或者on_session_close中有调用使用asyncio事件循环的调用，
@@ -327,25 +295,7 @@ class ScriptModeSession(ThreadBasedSession):
             raise RuntimeError("ScriptModeSession can only be created once.")
         ScriptModeSession.instance = self
 
-        ThreadBasedSession._active_session_cnt += 1
-
-        self._on_task_command = on_task_command or (lambda _: None)
-        self._on_session_close = lambda: None
-        self._loop = loop
-
-        # 会话结束时运行的函数
-        self.deferred_functions = []
-
-        self.threads = []  # 当前会话的线程
-        self.unhandled_task_msgs = LimitedSizeQueue(maxsize=self.unhandled_task_mq_maxsize)
-
-        self.task_mqs = {}  # task_id -> event msg queue
-        self._closed = False
-
-        # 用于实现回调函数的注册
-        self.callback_mq = None
-        self.callback_thread = None
-        self.callbacks = {}  # callback_id -> (callback_func, is_mutex)
+        super().__init__(target=None, session_info=session_info, on_task_command=on_task_command, loop=loop)
 
         tid = id(thread)
         event_mq = queue.Queue(maxsize=self.event_mq_maxsize)
